@@ -1,5 +1,5 @@
 package File::Format::CRD;
-$File::Format::CRD::VERSION = '0.2.1';
+$File::Format::CRD::VERSION = '0.2.2';
 use warnings;
 use strict;
 
@@ -21,40 +21,12 @@ File::Format::CRD - Distribution for reading the Windows CRD format.
 
 =head1 VERSION
 
-version 0.2.1
+version 0.2.2
 
 =head1 SYNOPSIS
 
 See L<File::Format::CRD::Reader> .
 
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc File::Format::CRD
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=File-Format-CRD>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/File-Format-CRD>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/File-Format-CRD>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/File-Format-CRD/>
-
-=back
-
 =head1 ACKNOWLEDGEMENTS
 
 This module is based on L<http://ihaa.com/english/crd2html.html> by
@@ -64,7 +36,7 @@ ihaa.com.
 
 Copyright 2010 Shlomi Fish.
 
-This program is distributed under the MIT (X11) License:
+This program is distributed under the MIT (Expat) License:
 L<http://www.opensource.org/licenses/mit-license.php>
 
 Permission is hereby granted, free of charge, to any person
