@@ -1,5 +1,5 @@
 package File::Format::CRD::Reader;
-$File::Format::CRD::Reader::VERSION = '0.2.1';
+$File::Format::CRD::Reader::VERSION = '0.2.2';
 use warnings;
 use strict;
 
@@ -186,7 +186,7 @@ File::Format::CRD::Reader - read Windows .CRD files.
 
 =head1 VERSION
 
-version 0.2.1
+version 0.2.2
 
 =head1 SYNOPSIS
 
@@ -231,40 +231,6 @@ certain encoding.
 
 Shlomi Fish, L<http://www.shlomifish.org/>
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-file-format-crd at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=File-Format-CRD>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc File::Format::CRD::Reader
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=File-Format-CRD>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/File-Format-CRD>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/File-Format-CRD>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/File-Format-CRD/>
-
-=back
-
 =head1 ACKNOWLEDGEMENTS
 
 This module is based on L<http://ihaa.com/english/crd2html.html> by
@@ -274,7 +240,7 @@ ihaa.com.
 
 Copyright 2010 Shlomi Fish.
 
-This program is distributed under the MIT (X11) License:
+This program is distributed under the MIT (Expat) License:
 L<http://www.opensource.org/licenses/mit-license.php>
 
 Permission is hereby granted, free of charge, to any person
